VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CDoc"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
' This class manages the displaying, saving, and loading of text files
Option Explicit

' private properties
Private m_oFace As Form ' reference to form used as interface of this CDoc instance
Private m_bNeedToSaveData As Boolean ' indicates that data needs to be saved
Private m_sFileName As String ' text file viewed/edited by CDoc instance

' public properties
Public ID As Long ' unique id number which idnetifies each CDoc instance
'  This procedure loads the text of the sFileToLoad into the text box of the form which is
'       used as the interface for this object
Public Function LoadFile(sFileToLoad As String) As Boolean

    
    On Error GoTo LoadFile_Error

    Screen.MousePointer = vbHourglass

    Dim iTextFileLength As Long
    Dim sErrorText As String ' error text to show user
    Dim iFileNum As Integer, iProgress As Integer
    Dim sTextLine As String, sTempText As String
    
    ' set the file of this object to the file that the calling procedure passed
    m_sFileName = sFileToLoad
    
    ' get the length of the file.   This test is better than using Dir$
    '   since Dir$("*.txt")<>"" in many cases may yield True.
    iTextFileLength = -1
    iTextFileLength = FileLen(m_sFileName)
    
    ' if the file exists then...
    If iTextFileLength > -1 Then
        If iTextFileLength < 32767 Then
            ' tell user that we are loading the file
            With Editor.Face
                Call .SetStatusText("Loading '" & LCase$(m_sFileName) & "'.  Please wait...")
                iFileNum = FreeFile
                ' *NOTE!  We are looping through the text file one line at a time just to have the status bar show the progress
                '   of the load process (for effect).  Had this been an actual application we would have loaded the entire text
                '   file in an instant with the following code fragment:
                                                    'Open m_sFileName For Input As iFileNum
                                                    'sTempText = Input(LOF(iFileNum), iFileNum)
                                                    'Close m_sFileName
                Open m_sFileName For Input As iFileNum
                Do Until EOF(iFileNum)
                    Line Input #iFileNum, sTextLine
                    sTempText = sTempText & sTextLine & vbCrLf
                    iProgress = 100 * (Len(sTempText) / iTextFileLength)
                    ' update mdi  form with progress
                    Call .SetProgress(iProgress)
                Loop
                Close iFileNum
                ' clear progress on the form
                Call .SetProgress(-1)
                ' remove last crlf
                If Len(sTempText) > 2 Then sTempText = Mid(sTempText, 1, (Len(sTempText) - 2))
                ' fill the text box with the text
                m_oFace.txtDoc.Text = sTempText
                ' since setting the text calls this object's DataHasChanged method we need to indicate that
                '   the data has not really changed quite yet
                m_bNeedToSaveData = False
                ' set caption of form
                m_oFace.Caption = m_sFileName
                ' clear status text
                Call .SetStatusText("")
            End With ' Editor.Face
        Else
            ' file too large
            sErrorText = "The file '" & sFileToLoad & "' is too large to be loaded."
        End If
    Else
        ' file not found
        sErrorText = "The file '" & sFileToLoad & "' was not found."
    End If
        
    Screen.MousePointer = vbDefault
    ' if the loading of the file that the user specified was not ok then just open a blank document
    '   and tell the user what happened
    If Len(sErrorText) Then
        MsgBox sErrorText & "  A blank document has been opened for you."
        ' indicate that the load was NOT successful
        LoadFile = False
    Else ' load ok
        ' indicate that the load was successful
        LoadFile = True
    End If
        

Exit Function
LoadFile_Error:
Resume Next
End Function
'  This procedure returns the setting of m_DatChanged which indicates whether
'       this object instance has data to save
Public Property Get NeedToSaveData() As Boolean


    NeedToSaveData = m_bNeedToSaveData
    
    
End Property
'  This procedure sets the m_bNeedToSaveData to true to indicate that data needs to be saved for this object instance
Public Sub DataHasChanged()

    
    m_bNeedToSaveData = True
    
    
End Sub
Public Property Let Caption(sNewValue As String)


    ' set caption of interface form
    m_oFace.Caption = sNewValue
    
    
End Property
Public Property Get Caption() As String


    ' return caption of interface form
     Caption = m_oFace.Caption
    
    
End Property
Public Function Save() As Boolean


    On Error GoTo Save_Error
        
    Dim iFileNum As Integer
    Dim sTempText As String
    
    Err.Number = 0
    ' if the filename is not empty then save the text to the named file
    If Trim$(m_sFileName) <> "" Then
        Screen.MousePointer = vbHourglass
        ' tell user what is going on
        Call Editor.Face.SetStatusText("Saving '" & LCase$(m_sFileName) & "'.  Please wait...")
        iFileNum = FreeFile
        ' grab text from the form
        sTempText = m_oFace.txtDoc.Text
        ' open the file
        Open m_sFileName For Output As iFileNum
        ' save the text to the file
        Print #iFileNum, sTempText
        ' close the file
        Close iFileNum
        '   indicate that the data in this object no longer needs to be saved
        m_bNeedToSaveData = False
        ' clear status text
        Call Editor.Face.SetStatusText("")
        Screen.MousePointer = vbDefault
        ' succesful save if there was no error
        If Not Err.Number Then Save = True
    End If

    
Exit Function
Save_Error:
If Editor.ProgramError Then Resume
Resume Next
End Function
Public Property Get FileName() As String


    ' return the file name
    FileName = m_sFileName
    
    
End Property
Public Property Let FileName(sFileName As String)


    ' set the new file name
    m_sFileName = sFileName
    ' and set the caption to match
    m_oFace.Caption = m_sFileName
    
    
End Property
Public Sub CloseDown()


    ' have myself removed from the CDocs collection and then terminated
    Call Editor.RemoveDocument(Me)
    
    
End Sub
Public Property Set Face(oNewFace As Form)


    Set m_oFace = oNewFace
    
    
End Property
Public Property Get Face() As Form

    
    Set Face = m_oFace
    

End Property
